/* Copyright (c) 2015 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

#include "nrf_drv_spi.h"
#include "app_util_platform.h"
#include "nrf_gpio.h"
#include "nrf_delay.h"
#include "nrf_log.h"
#include "boards.h"
#include "app_error.h"
#include <string.h>

#if defined(BOARD_PCA10036) || defined(BOARD_PCA10040)
#define SPI_CS_PIN   29 /**< SPI CS Pin.*/
#elif defined(BOARD_PCA10028)
#define SPI_CS_PIN   4  /**< SPI CS Pin.*/
#else
#error "Example is not supported on that board."
#endif

#define SPI_INSTANCE  0 /**< SPI instance index. */
static const nrf_drv_spi_t spi = NRF_DRV_SPI_INSTANCE(SPI_INSTANCE);  /**< SPI instance. */
static volatile bool spi_xfer_done;  /**< Flag used to indicate that SPI instance completed the transfer. */

//#define TEST_STRING "Nordic"
static uint8_t       m_tx_buf[2] ,   m_tx_buf1[2]  , m_tx_buf2[2] , m_tx_buf3[3]  ;    /**< TX buffer. */
static uint8_t       m_rx_buf[2] ,	 m_rx_buf1[2]  , m_rx_buf2[2] , m_rx_buf3[3];  	/**< RX buffer. */
//static const uint8_t m_length = sizeof(m_tx_buf);     /**< Transfer length. */

/**
 * @brief SPI user event handler.
 * @param event
 */
void spi_event_handler(nrf_drv_spi_evt_t const * p_event)
{
    spi_xfer_done = true;
    NRF_LOG_PRINTF(" Transfer completed.\r\n");
    if (m_rx_buf[0] != 0)
    {
        NRF_LOG_PRINTF(" Received: %s\r\n",m_rx_buf);
    }
}

int main(void)
{
//    LEDS_CONFIGURE(BSP_LED_0_MASK);
//    LEDS_OFF(BSP_LED_0_MASK);

    APP_ERROR_CHECK(NRF_LOG_INIT());
    NRF_LOG_PRINTF("SPI example\r\n");
	
		nrf_drv_spi_config_t spi_config;
    spi_config.ss_pin = SPI_CS_PIN;
    spi_config.mosi_pin = SPI0_CONFIG_MOSI_PIN;
    spi_config.sck_pin = SPI0_CONFIG_SCK_PIN;
    spi_config.miso_pin = SPI0_CONFIG_MISO_PIN;
    spi_config.frequency = NRF_DRV_SPI_FREQ_2M;         
    spi_config.mode = NRF_DRV_SPI_MODE_0;           
    spi_config.bit_order = NRF_DRV_SPI_BIT_ORDER_MSB_FIRST; // Matches Default.
//    spi_config.irq_priority = 6;//SPI0_CONFIG_IRQ_PRIORITY;

//    nrf_drv_spi_config_t spi_config = NRF_DRV_SPI_DEFAULT_CONFIG(SPI_INSTANCE);
    spi_config.ss_pin = SPI_CS_PIN;
    APP_ERROR_CHECK(nrf_drv_spi_init(&spi, &spi_config, spi_event_handler));

    while(1)
    {
        // Reset rx buffer and transfer done flag
//        memset(m_rx_buf, 0, 2);
//        spi_xfer_done = false;
			
			
//				m_tx_buf[0]=0xE0;//SPI send command
//				m_tx_buf[1]=0x02;//SPi send command
//			

//				
//        APP_ERROR_CHECK(nrf_drv_spi_transfer(&spi,m_tx_buf, 2, m_rx_buf, 2));

//        while (!spi_xfer_done)
//        {
//            __WFE();
//        }
			
				memset(m_rx_buf1, 0, 2);
        spi_xfer_done = false;
			
				m_tx_buf1[0]=0xE3;//Transponder enabled  
				//m_tx_buf1[1]=0x00;//dummy command
				
				APP_ERROR_CHECK(nrf_drv_spi_transfer(&spi, m_tx_buf1, 2, m_rx_buf1, 2));

        while (!spi_xfer_done)
        {
            __WFE();
        }

				
				memset(m_rx_buf2, 0, 2);
        spi_xfer_done = false;
				
				m_tx_buf2[0]=0xE8;//write command
				m_tx_buf2[1]=0x2C;//address in em4325
				
				APP_ERROR_CHECK(nrf_drv_spi_transfer(&spi, m_tx_buf2, 2, m_rx_buf2, 2));

        while (!spi_xfer_done)
        {
            __WFE();
        }
				
				memset(m_rx_buf3, 0, 3);
        spi_xfer_done = false;
				
				//data to be stored in 0x2C mem location of EM4325
				m_tx_buf3[0]=0x1F;
				m_tx_buf3[1]=0x2F;
				m_tx_buf3[2]=0x3F;
				
				APP_ERROR_CHECK(nrf_drv_spi_transfer(&spi, m_tx_buf3, 3, m_rx_buf3, 3));

        while (!spi_xfer_done)
        {
            __WFE();
        }
				
        LEDS_INVERT(BSP_LED_0_MASK);
        nrf_delay_ms(200);
				
	
    }
}
